@@ -24,7 +24,8 @@ from __future__ import annotations
 import asyncio
 import copy
 from datetime import datetime
-from typing import overload, Optional, Union, List, TYPE_CHECKING, TypeVar, Dict, Any
+from typing import overload, Optional, Union, List, TYPE_CHECKING, TypeVar, Dict, Any, runtime_checkable, Protocol, \
+    Tuple
 
 from .asset import Asset
 from .enum import ChannelType
@@ -34,16 +35,18 @@ from .mention import AllowedMentions
 from .utils import MISSING
 
 if TYPE_CHECKING:
+    from .user import ClientUser
+    from .embeds import Ark, Embed
     from .member import Member
-    from .channel import CategoryChannel, TextChannel, PartialMessageable
+    from .channel import CategoryChannel, TextChannel, PartialMessageable, DMChannel
     from .guild import Guild
     from .state import ConnectionState
-    from .message import Message, MessageReference, PartialMessage
+    from .message import Message, MessageReference, PartialMessage, MessageAudit
     from .types.channel import (
         Channel as ChannelPayload,
     )
 
-    PartialMessageableChannel = Union[TextChannel, PartialMessageable]
+    PartialMessageableChannel = Union[TextChannel, PartialMessageable, DMChannel]
     MessageableChannel = Union[PartialMessageableChannel]
 
 __all__ = (
@@ -61,6 +64,26 @@ class _Undefined:
 _undefined: Any = _Undefined()
 
 
+@runtime_checkable
+class PrivateChannel(Protocol):
+    """详细说明私人QQ频道上的常见操作的抽象类。
+
+    以下实现了这个 ABC：
+
+    - :class:`~qq.DMChannel`
+
+    Attributes
+    -----------
+    me: :class:`~discord.ClientUser`
+        代表你自己的用户。
+    """
+
+    __slots__ = ()
+
+    me: ClientUser
+    id: int
+
+
 class Messageable:
     """一个 记录了可以发送消息的模型上的常见操作的ABC。
 
@@ -76,7 +99,7 @@ class Messageable:
     __slots__ = ()
     _state: ConnectionState
 
-    async def _get_channel(self) -> MessageableChannel:
+    async def _get_channel(self) -> Tuple[MessageableChannel, bool]:
         raise NotImplementedError
 
     @overload
@@ -90,7 +113,8 @@ class Messageable:
             image: str = ...,
             reference: Union[Message, MessageReference, PartialMessage] = ...,
             mention_author: Member = ...,
-    ) -> Message:
+            direct=...,
+    ) -> Union[Message, str]:
         ...
 
     async def send(
@@ -102,12 +126,13 @@ class Messageable:
             mention_author=None,
             ark=None,
             embed=None,
-            delete_after = None,
+            delete_after=None,
     ):
         """|coro|
         使用给定的内容向目的地发送消息。
         content 必须是可以通过 ``str(content)`` 转换为字符串的类型。
-        如果是主动信息，不一定会有返回。
+        如果不填入 ``reference`` 将会被腾讯视为主动消息。
+        如果是主动信息，输出将会是 ``audit_id``。
 
         Parameters
         ------------
@@ -138,11 +163,11 @@ class Messageable:
 
         Returns
         ---------
-        :class:`~qq.Message`
+        Union[:class:`~qq.Message`, :class:`~qq.MessageAudit`]
             发送的消息。
         """
 
-        channel = await self._get_channel()
+        channel, direct = await self._get_channel()
         state = self._state
         content = str(content) if content is not None else None
 
@@ -162,13 +187,14 @@ class Messageable:
             ark=ark,
             message_reference=reference,
             image_url=image,
-            embed=embed
+            embed=embed,
+            direct=direct
         )
 
-        if 'code' in data:
-            return None
+        if reference is None:
+            return data['data']['message_audit']['audit_id']
 
-        ret = state.create_message(channel=channel, data=data)
+        ret = state.create_message(channel=channel, data=data, direct=direct)
         if delete_after is not None:
             await ret.delete(delay=delete_after)
         return ret
@@ -197,19 +223,18 @@ class Messageable:
             消息要求。
         """
         id = id
-        channel = await self._get_channel()
+        channel, direct = await self._get_channel()
         data = await self._state.http.get_message(channel.id, id)
-        return self._state.create_message(channel=channel, data=data)
-
+        return self._state.create_message(channel=channel, data=data, direct=direct)
 
     def history(
-        self,
-        *,
-        limit: Optional[int] = 100,
-        before: Optional[datetime] = None,
-        after: Optional[datetime] = None,
-        around: Optional[datetime] = None,
-        oldest_first: Optional[bool] = None,
+            self,
+            *,
+            limit: Optional[int] = 100,
+            before: Optional[datetime] = None,
+            after: Optional[datetime] = None,
+            around: Optional[datetime] = None,
+            oldest_first: Optional[bool] = None,
     ) -> HistoryIterator:
         """返回允许接收目标消息历史记录的 :class:`~qq.AsyncIterator`。
 
@@ -259,7 +284,6 @@ class Messageable:
         return HistoryIterator(self, limit=limit, before=before, after=after, around=around, oldest_first=oldest_first)
 
 
-
 GCH = TypeVar('GCH', bound='GuildChannel')
 
 
