@@ -24,7 +24,7 @@ from __future__ import annotations
 import asyncio
 import datetime
 import time
-from typing import TYPE_CHECKING, Iterable, Optional, List, overload, Callable
+from typing import TYPE_CHECKING, Iterable, Optional, List, overload, Callable, TypeVar, Type, Tuple
 
 from . import abc, utils
 from .error import ClientException
@@ -40,11 +40,13 @@ __all__ = (
     'CategoryChannel',
     'ThreadChannel',
     'PartialMessageable',
+    'DMChannel'
 )
 
 from .utils import MISSING
 
 if TYPE_CHECKING:
+    from .user import *
     from .member import Member
     from .message import Message, PartialMessage
     from .state import ConnectionState
@@ -55,7 +57,8 @@ if TYPE_CHECKING:
         CategoryChannel as CategoryChannelPayload,
         LiveChannel as LiveChannelPayload,
         AppChannel as AppChannelPayload,
-        ThreadChannel as ThreadChannelPayload
+        ThreadChannel as ThreadChannelPayload,
+        DMChannel as DMChannelPayload,
     )
 
 
@@ -152,7 +155,7 @@ class TextChannel(abc.Messageable, abc.GuildChannel, Hashable):
         self.private_type: int = data.get('private_type')
 
     async def _get_channel(self):
-        return self
+        return self, False
 
     @property
     def type(self) -> ChannelType:
@@ -860,8 +863,8 @@ class PartialMessageable(abc.Messageable, Hashable):
         self.id: int = id
         self.type: Optional[ChannelType] = type
 
-    async def _get_channel(self) -> Object:
-        return self._channel
+    async def _get_channel(self) -> Tuple[Object, bool]:
+        return self._channel, True
 
     def get_partial_message(self, message_id: int, /) -> PartialMessage:
         from .message import PartialMessage
@@ -890,3 +893,87 @@ def _guild_channel_factory(channel_type: int):
 def _channel_factory(channel_type: int):
     cls, value = _guild_channel_factory(channel_type)
     return cls, value
+
+
+DMC = TypeVar('DMC', bound='DMChannel')
+
+
+class DMChannel(abc.Messageable, Hashable):
+    """代表一个QQ私信子频道。
+    
+    .. container:: operations
+        .. describe:: x == y
+            检查两个子频道是否相等。
+        .. describe:: x != y
+            检查两个子频道是否不相等。
+        .. describe:: hash(x)
+            返回子频道的哈希值。
+        .. describe:: str(x)
+            返回子频道的字符串表示形式
+
+    Attributes
+    ----------
+    recipient: Optional[:class:`User`]
+        在私信子频道中参与的用户。如果通过网关接收此子频道，则接收者信息可能并不总是可用。
+    me: :class:`ClientUser`
+        代表你自己的用户。
+    id: :class:`int`
+        私信会话关联的子频道 id
+    channel_id: :class:`int`
+        垃圾资讯，无视即可，官方不知道在搞什么jb东西
+    """
+
+    __slots__ = ('id', 'recipient', 'me', 'channel_id', '_state')
+
+    def __init__(self, *, me: ClientUser, state: ConnectionState, data: DMChannelPayload, recipients: User):
+        self._state: ConnectionState = state
+        self.recipient: Optional[User] = recipients
+        self.me: ClientUser = me
+        self.id: int = int(data['guild_id'])
+        self.channel_id: int = int(data['channel_id'])
+
+    async def _get_channel(self):
+        return self, True
+
+    def __str__(self) -> str:
+        if self.recipient:
+            return f'与 {self.recipient} 的直接消息'
+        return '与未知用户的直接消息'
+
+    def __repr__(self) -> str:
+        return f'<DMChannel id={self.id} guild_id={self.channel_id} recipient={self.recipient!r}>'
+
+    @classmethod
+    def _from_message(cls: Type[DMC], state: ConnectionState, channel_id: int, guild_id: int) -> DMC:
+        self: DMC = cls.__new__(cls)
+        self._state = state
+        self.channel_id = channel_id
+        self.id = guild_id
+        self.recipient = None
+        # state.user won't be None here
+        self.me = state.user  # type: ignore
+        return self
+
+    @property
+    def type(self) -> ChannelType:
+        """:class:`ChannelType`: 频道的 QQ 类型。"""
+        return ChannelType.private
+
+    def get_partial_message(self, message_id: int, /) -> PartialMessage:
+        """从消息 ID 创建一个 :class:`PartialMessage` 。
+        如果您想处理消息并且只拥有其 ID 而不进行不必要的 API 调用，这将非常有用。
+
+        Parameters
+        ------------
+        message_id: :class:`int`
+            要为其创建部分消息的消息 ID。
+
+        Returns
+        ---------
+        :class:`PartialMessage`
+            部分消息。
+        """
+
+        from .message import PartialMessage
+
+        return PartialMessage(channel=self, id=message_id)
