@@ -36,6 +36,7 @@ from typing import (
 )
 
 from . import utils, abc
+from .api_permission import Permission
 from .role import Role
 from .member import Member
 from .error import InvalidData, HTTPException
@@ -118,6 +119,7 @@ class Guild(Hashable):
         '_roles',
         '_state',
         '_large',
+        '_permission',
         'unavailable'
     )
 
@@ -148,6 +150,7 @@ class Guild(Hashable):
         self.joined_at = guild.get('joined_at')
         self.unavailable: bool = guild.get('unavailable', False)
         self._roles: Dict[int, Role] = {}
+        self._permission: List[Permission] = []
         state = self._state  # speed up attribute access
         self._large: Optional[bool] = None if self._member_count is None else self._member_count >= 250
         for r in guild.get('roles', []):
@@ -177,17 +180,22 @@ class Guild(Hashable):
         # I know it's jank to put a sync requests here,
         # but QQ just does not give all the info about guilds unless you requests it
         channels = asyncio.run(self._state.http.get_guild_channels(self.id))
+        result = asyncio.run(self._state.http.get_member(self.id, self._state.user.id))
+
+        member = Member(data=result,
+                        guild=self, state=self._state)
+        self._add_member(member)
+
         try:
-            members = asyncio.run(self._state.http.get_members(self.id, 500))
-            for mdata in members:
-                member = Member(data=mdata, guild=self, state=self._state)
-                self._add_member(member)
-        except HTTPException:
-            result = asyncio.run(self._state.http.get_member(self.id, self._state.user.id))
+
+            permissions = asyncio.run(self._state.http.get_permission(self.id))
+            for permission in permissions['apis']:
+                permission = Permission(data=permission, state=self._state, guild=self)
+                self._permission.append(permission)
+
+        except Exception as e:
+            print(e)
 
-            member = Member(data=result,
-                            guild=self, state=self._state)
-            self._add_member(member)
         try:
             roles = asyncio.run(self._state.http.get_roles(self.id))
             if 'roles' in roles:
@@ -201,6 +209,30 @@ class Guild(Hashable):
             if factory:
                 self._add_channel(factory(guild=self, data=c, state=self._state))  # type: ignore
 
+    @property
+    def permissions(self) -> List[Permission]:
+        """List[:class:`qq.Permission`]: 属于该频道的权限列表。"""
+        return self._permission
+
+    def get_permission(self, path: str, method: str) -> Optional[Permission]:
+        """返回具有给定 path 和 method 的权限。
+
+        Parameters
+        -----------
+        path: :class:`str`
+            要搜索的 path。
+        method: :class:`str`
+            要搜索的 method。
+
+        Returns
+        --------
+        Optional[:class:`Permission`]
+            Role 或如果未找到，则  ``None`` 。
+        """
+        for perm in self._permission:
+            if perm.path == path and perm.method == method:
+                return perm
+
     @property
     def channels(self) -> List[GuildChannel]:
         """List[:class:`abc.GuildChannel`]: 属于该频道的子频道列表。"""
@@ -697,7 +729,7 @@ class Guild(Hashable):
 
         return [convert(d) for d in data]
 
-    def fetch_members(self, *, limit: int = 1000) -> MemberIterator:
+    def fetch_members(self, *, limit: int = 1000, after: int = 0) -> MemberIterator:
         """检索一个 :class:`.AsyncIterator` 来接收频道的成员。为了使用它，必须启用:meth:`Intents.members`。
 
         .. note::
@@ -706,7 +738,9 @@ class Guild(Hashable):
         Parameters
         ----------
         limit: Optional[:class:`int`]
-            要检索的成员数。默认为 1000。传递 ``无`` 以获取所有成员。请注意，这可能很慢。
+            要检索的成员数。默认为 1000。传递 ``None`` 以获取所有成员。请注意，这可能很慢。
+        after: Optional[Union[:class:`qq.Member`, :class:`int`]]
+            检索这个成员 id 之后的成员
 
         Raises
         ------
@@ -737,7 +771,7 @@ class Guild(Hashable):
         if not self._state._intents.members:
             raise ClientException('Intents.members must be enabled to use this.')
 
-        return MemberIterator(self, limit=limit)
+        return MemberIterator(self, limit=limit, after=after)
 
     async def fetch_member(self, member_id: int, /) -> Member:
         """|coro|
